operator

package
v1.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: Apache-2.0 Imports: 51 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckEC2Connectivity

func CheckEC2Connectivity(ctx context.Context, api sdk.EC2API) error

CheckEC2Connectivity makes a dry-run call to DescribeInstanceTypes. If it fails, we provide an early indicator that we are having issues connecting to the EC2 API.

func GetCABundle

func GetCABundle(ctx context.Context, restConfig *rest.Config) (*string, error)

func KubeDNSIP

func KubeDNSIP(ctx context.Context, kubernetesInterface kubernetes.Interface) (net.IP, error)

func ResolveClusterEndpoint

func ResolveClusterEndpoint(ctx context.Context, eksAPI sdk.EKSAPI) (string, error)

func SetupIndexers

func SetupIndexers(ctx context.Context, mgr manager.Manager)

func ValidateZonalShiftEnablement added in v1.12.0

func ValidateZonalShiftEnablement(ctx context.Context, eksAPI sdk.EKSAPI, arczonalshiftAPI sdk.ARCZonalShiftAPI) (string, error)

func WithUserAgent

func WithUserAgent(cfg aws.Config) aws.Config

WithUserAgent adds a karpenter specific user-agent string to AWS session

Types

type Operator

type Operator struct {
	*operator.Operator
	Config                      aws.Config
	UnavailableOfferingsCache   *awscache.UnavailableOfferings
	SSMCache                    *cache.Cache
	ValidationCache             *cache.Cache
	RecreationCache             *cache.Cache
	SubnetProvider              subnet.Provider
	SecurityGroupProvider       securitygroup.Provider
	InstanceProfileProvider     instanceprofile.Provider
	AMIProvider                 amifamily.Provider
	AMIResolver                 amifamily.Resolver
	LaunchTemplateProvider      launchtemplate.Provider
	PricingProvider             pricing.Provider
	VersionProvider             *version.DefaultProvider
	InstanceTypesProvider       *instancetype.DefaultProvider
	InstanceProvider            instance.Provider
	InstanceStatusProvider      *instancestatus.DefaultProvider
	SSMProvider                 ssmp.Provider
	CapacityReservationProvider capacityreservation.Provider
	PlacementGroupProvider      placementgroup.Provider
	EC2API                      *kwokec2.Client
	ZonalShiftProvider          zonalshiftprovider.Provider
}

Operator is injected into the AWS CloudProvider's factories

func NewOperator

func NewOperator(ctx context.Context, operator *operator.Operator) (context.Context, *Operator)

Jump to